@@ -1,16 +1,16 @@
 # frozen_string_literal: true
 
 module Rails
-  # Returns the version of the currently loaded Rails as a <tt>Gem::Version</tt>
+  # Returns the currently loaded version of \Rails as a +Gem::Version+.
   def self.gem_version
     Gem::Version.new VERSION::STRING
   end
 
   module VERSION
-    MAJOR = 6
+    MAJOR = 7
     MINOR = 1
-    TINY  = 7
-    PRE   = "7"
+    TINY  = 4
+    PRE   = nil
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
